==> polarion_rest_api_client-1.2.0-py3-none-any.whl: polarion_rest_api_client/open_api_client/models/testparameter_definitions_list_post_response_data_item.py <==
# Copyright DB InfraGO AG and contributors
# SPDX-License-Identifier: Apache-2.0

from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.testparameter_definitions_list_post_response_data_item_type import (
    TestparameterDefinitionsListPostResponseDataItemType,
)
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.testparameter_definitions_list_post_response_data_item_links import (
        TestparameterDefinitionsListPostResponseDataItemLinks,
    )


T = TypeVar("T", bound="TestparameterDefinitionsListPostResponseDataItem")


@_attrs_define
class TestparameterDefinitionsListPostResponseDataItem:
    """
    Attributes:
        type (Union[Unset, TestparameterDefinitionsListPostResponseDataItemType]):
        id (Union[Unset, str]):  Example: MyProjectId/MyTestParamDefinition.
        links (Union[Unset, TestparameterDefinitionsListPostResponseDataItemLinks]):
    """

    type: Union[
        Unset, TestparameterDefinitionsListPostResponseDataItemType
    ] = UNSET
    id: Union[Unset, str] = UNSET
    links: Union[
        Unset, "TestparameterDefinitionsListPostResponseDataItemLinks"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        id = self.id

        links: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.links, Unset):
            links = self.links.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if type is not UNSET:
            field_dict["type"] = type
        if id is not UNSET:
            field_dict["id"] = id
        if links is not UNSET:
            field_dict["links"] = links

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.testparameter_definitions_list_post_response_data_item_links import (
            TestparameterDefinitionsListPostResponseDataItemLinks,
        )

        d = src_dict.copy()
        _type = d.pop("type", UNSET)
        type: Union[
            Unset, TestparameterDefinitionsListPostResponseDataItemType
        ]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = TestparameterDefinitionsListPostResponseDataItemType(_type)

        id = d.pop("id", UNSET)

        _links = d.pop("links", UNSET)
        links: Union[
            Unset, TestparameterDefinitionsListPostResponseDataItemLinks
        ]
        if isinstance(_links, Unset):
            links = UNSET
        else:
            links = TestparameterDefinitionsListPostResponseDataItemLinks.from_dict(
                _links
            )

        testparameter_definitions_list_post_response_data_item_obj = cls(
            type=type,
            id=id,
            links=links,
        )

        testparameter_definitions_list_post_response_data_item_obj.additional_properties = (
            d
        )
        return testparameter_definitions_list_post_response_data_item_obj

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> polarion_rest_api_client-1.4.1-py3-none-any.whl: polarion_rest_api_client/open_api_client/models/testparameter_definitions_list_post_response_data_item.py <==
# Copyright DB InfraGO AG and contributors
# SPDX-License-Identifier: Apache-2.0

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.testparameter_definitions_list_post_response_data_item_type import (
    TestparameterDefinitionsListPostResponseDataItemType,
)
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.testparameter_definitions_list_post_response_data_item_links import (
        TestparameterDefinitionsListPostResponseDataItemLinks,
    )


T = TypeVar("T", bound="TestparameterDefinitionsListPostResponseDataItem")


@_attrs_define
class TestparameterDefinitionsListPostResponseDataItem:
    """
    Attributes:
        type_ (Union[Unset, TestparameterDefinitionsListPostResponseDataItemType]):
        id (Union[Unset, str]):  Example: MyProjectId/MyTestParamDefinition.
        links (Union[Unset, TestparameterDefinitionsListPostResponseDataItemLinks]):
    """

    type_: Union[
        Unset, TestparameterDefinitionsListPostResponseDataItemType
    ] = UNSET
    id: Union[Unset, str] = UNSET
    links: Union[
        Unset, "TestparameterDefinitionsListPostResponseDataItemLinks"
    ] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> dict[str, Any]:
        type_: Union[Unset, str] = UNSET
        if not isinstance(self.type_, Unset):
            type_ = self.type_.value

        id = self.id

        links: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.links, Unset):
            links = self.links.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if type_ is not UNSET:
            field_dict["type"] = type_
        if id is not UNSET:
            field_dict["id"] = id
        if links is not UNSET:
            field_dict["links"] = links

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.testparameter_definitions_list_post_response_data_item_links import (
            TestparameterDefinitionsListPostResponseDataItemLinks,
        )

        d = dict(src_dict)
        _type_ = d.pop("type", UNSET)
        type_: Union[
            Unset, TestparameterDefinitionsListPostResponseDataItemType
        ]
        if isinstance(_type_, Unset):
            type_ = UNSET
        else:
            type_ = TestparameterDefinitionsListPostResponseDataItemType(
                _type_
            )

        id = d.pop("id", UNSET)

        _links = d.pop("links", UNSET)
        links: Union[
            Unset, TestparameterDefinitionsListPostResponseDataItemLinks
        ]
        if isinstance(_links, Unset):
            links = UNSET
        else:
            links = TestparameterDefinitionsListPostResponseDataItemLinks.from_dict(
                _links
            )

        testparameter_definitions_list_post_response_data_item_obj = cls(
            type_=type_,
            id=id,
            links=links,
        )

        testparameter_definitions_list_post_response_data_item_obj.additional_properties = (
            d
        )
        return testparameter_definitions_list_post_response_data_item_obj

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
